@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2007..2018 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2007..2022 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,13 +24,14 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2007..2018 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: descript.c,v 1.70 2018/08/20 22:30:00 babolo Exp $"
+#ident "@(#) Copyright (C)2007..2022 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: descript.c,v 1.97 2022/01/23 14:19:59 babolo Exp $"
 
-#define BLIN_COMPAT      3
+#define BLIN_COMPAT      4
 #define Bpars_COMPAT     3
-#define MIFE_COMPAT      4
-#define PGOBLIN_COMPAT   2
+#define MULAR_COMPAT     0
+#define MIFE_COMPAT      5
+#define PGOBLIN_COMPAT   4
 #define PGOBLIN_INTERNAL 1
 
 #include <sys/types.h>
@@ -39,6 +40,7 @@
 #include <stdio.h>
 #include <babolo/BLINflag.h>
 #include <babolo/parser.h>
+#include <multilar.h>
 #include <mife.h>
 #include "pgoblin.h"
 #include "cmds.h"
@@ -60,6 +62,7 @@
 #define Fe PGOBLIN_EXTENDED
 #define Fu PGOBLIN_LEXLVUP
 #define Fd PGOBLIN_LEXLDOWN
+#define Fc PGOBLIN_CTLCORTG
 #define Io PGOBLIN_OUTSET
 #define Id PGOBLIN_CTL
 #define Ii PGOBLIN_ISIN
@@ -139,26 +142,26 @@ const char * const pgoblin_syntaxa_flags[] =
 };
 
 const pgoblin_syntax pgoblin =
-{ PGOBLIN_DBTABLESZ                                             // dbtablesz
-, PGOBLIN_JOBTABSIZ                                             // jobtabsiz
-, PGOBLIN_STYLETBSZ                                             // styletbsz
-, PGOBLIN_SYMREGS                                               // symparam
-, PGOBLIN_BINREGS                                               // binparam
-, PGOBLIN_REGSIZE                                               // regsize
-, PGOBLIN_max                                                   // max
-, dbasetable                                                    // dbasetable
-, jobtable                                                      // jobtable
-, styletable                                                    // styletable
-, &cmds                                                         // cmds
-, &sqlkeywords                                                  // sqlkeywords
-, {PGOBLIN_ARG1S, PGOBLIN_ARG2S, PGOBLIN_ARG3S, PGOBLIN_ARG4S}  // binparams
-, { { PGOBLIN_OUTSET , PGOBLIN_ANYIVL ,  0, 0, "out  "}         // p[0].sym .val .bin .mask .name
-  , { PGOBLIN_CTL    , PGOBLIN_ANYIVL ,  1, 0, "ctl  "}         // p[1]
-  , { PGOBLIN_ISIN   , PGOBLIN_ANYIVL ,  3, 0, "in   "}         // p[2]
-  , { PGOBLIN_CONNECT, PGOBLIN_CONNECT,  2, 0, "conn "}         // p[3]
-  , { PGOBLIN_JOB    , PGOBLIN_JOB    ,  2, 0, "job  "}         // p[4]
-  , { PGOBLIN_STYLE  , PGOBLIN_STYLE  ,~12, 3, "style"}         // p[5]
-  }                                                             // p
+{ PGOBLIN_DBTABLESZ                                            // dbtablesz
+, PGOBLIN_JOBTABSIZ                                            // jobtabsiz
+, PGOBLIN_STYLETBSZ                                            // styletbsz
+, PGOBLIN_SYMREGS                                              // symparam
+, PGOBLIN_BINREGS                                              // binparam
+, PGOBLIN_REGSIZE                                              // regsize
+, PGOBLIN_max                                                  // max
+, dbasetable                                                   // dbasetable
+, jobtable                                                     // jobtable
+, styletable                                                   // styletable
+, &cmds                                                        // cmds
+, &sqlkeywords                                                 // sqlkeywords
+, {PGOBLIN_ARG1S, PGOBLIN_ARG2S, PGOBLIN_ARG3S, PGOBLIN_ARG4S} // binparams
+, { { PGOBLIN_OUTSET , PGOBLIN_ANYIVL ,  0, 0, "out"}          // Po,F  p[0].sym .val .bin .mask .name
+  , { PGOBLIN_CTL    , PGOBLIN_ANYIVL ,  1, 0, "ctl"}          // Id,F  p[1]
+  , { PGOBLIN_ISIN   , PGOBLIN_ANYIVL ,  3, 0, "in "}          // Ii,F  p[2]
+  , { PGOBLIN_CONNECT, PGOBLIN_CONNECT,  2, 0, "db "}          // Ic,Ic p[3]
+  , { PGOBLIN_JOB    , PGOBLIN_JOB    ,  2, 0, "job"}          // Ij,Ij p[4]
+  , { PGOBLIN_STYLE  , PGOBLIN_STYLE  ,~12, 3, "sty"}          // Is,Is p[5]
+  }                                                            // p
 /*
  *  a[].flags       I.odicjs,    .
  *  a[].ch[PGOBLIN_BINREGS]     ,
@@ -176,11 +179,22 @@ const pgoblin_syntax pgoblin =
  */
 , { { Fe                      , {    0,     0,     0,    0}, NULL           , ""         } /* 000 */
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
-  , {                        0, {    0,     0,     0,    0}, NULL           , ""         }
-//      Pq  CTL,      Pq.
+  , {                        0, {    0,     0,     0,    0}, NULL /* cont */, ""         } /* 002 */
+//     
+//a
+// Pq
+//a
+// 
+//a
+// CTL
+//a
+// ,     
+//a
+// Pq
+//a .
 //      , .
 //     .
-  , { Fi                      , {    0,     0,     0,    0}, NULL           , "!"        }
+  , { Fi                      , {    0,     0,     0,    0}, NULL           , "!"        } /* 003 */
 //       
 //e
 // #!/usr/local/bin/pgoblin
@@ -200,14 +214,29 @@ const pgoblin_syntax pgoblin =
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
 
   , {       Id|   Ic          , {    0,    Pt, Po|Pc,    0}, pgoblin_connect, "connect"  } /* 010 */
-//  ,   CTL   ,   CON.
-// CTL     ,  
+//  ,  
+//a
+// CTL
+//a
+//   ,  
+//a
+// CON
+//a
+// .
+//a
+// CTL
+//a
+//     ,  
 //      .
 //         ,
 //      ,    ..
-  , {       Id|Ii|Ic          , {    0,    Pt,    Pc,   Pt}, pgoblin_listen , "listen"   } /* 011 */
+  , {    Io|Id|Ii|Ic          , {Po|Pq,    Pt,    Pc,   Pt}, pgoblin_listen , "listen"   } /* 011 */
 //  notify  ,   CTL.    ,
-//     IN.
+//     IN.  NOTIFY  
+//a
+// Po
+//a
+// ,    0.
 
 // !      
 //   64     
@@ -221,14 +250,48 @@ const pgoblin_syntax pgoblin =
 //         ) * 1000000
 //        )::int8
 //e
-// !     Pq,
-//      .    
+// !    
+//a
+// Pq
+//a
+// ,      .    
 //    .
-  , { Ff|Io|Id|Ii|   Ij       , {Po|Pm,    Pq,    Pj,   Pm}, pgoblin_exec   , "exec"     } /* 012 */
-//     JOB ,   
-// CTL,       Pq  CTL.
-// stdin  stdout      IN  OUT.
-//          JOB.
+  , { Ff|Io|Id|Ii|   Ij|    Fc, {Po|Pm,    Pq,    Pj,   Pm}, pgoblin_exec   , "exec"     } /* 012 */
+//    
+//a
+// JOB
+//a
+// ,   
+// CTL,      
+//a
+// Pq
+//a
+// 
+//a
+// CTL
+//a
+// .
+//a
+// stdin
+//a
+// 
+//a
+// stdout
+//a
+//     
+//a
+// IN
+//a
+// 
+//a
+// OUT
+//a
+// .
+//         
+//a
+// JOB
+//a
+// .
 // ,       ,
 //   - . NULL      
 //      / ,    .
@@ -236,29 +299,90 @@ const pgoblin_syntax pgoblin =
 //  ,    ,
 //    .
 //     ,    
-//     (#return  #exit)  ,   .
+//     (
+//a
+// #return
+//a
+// 
+//a
+// #exit
+//a
+// )  ,   .
   , { Fx                      , {    0,     0,     0,    0}, pgoblin_call   , "call"     } /* 014 */
   , {       Id                , {    0,    Pt,     0,    0}, pgoblin_eval   , "eval"     } /* 015 */
-// CTL     pgoblin.
+//a
+// CTL
+//a
+//    
+//a
+// pgoblin
+//a
+// .
 //          ,
 //     #trap.
-//   #trap    ,
+//  
+//a
+// #trap
+//a
+//    ,
 //        
-// #trap   .
-//   #trap  ,  
+//a
+// #trap
+//a
+//   .
+//  
+//a
+// #trap
+//a
+//  ,  
 //          .
   , {       Id|Ii|   Is|0x2000, {    0,    Pt,    Ps,   Pt}, pgoblin_style  , "style"    } /* 016 */
-//    STY  ,   CTL,
-//   ,    IN.
-//  0  STY   ,  
+//   
+//a
+// STY
+//a
+//  ,  
+//a
+// CTL
+//a
+// ,
+//   ,   
+//a
+// IN
+//a
+// .
+//  0 
+//a
+// STY
+//a
+//   ,  
 //      .
-//  CTL     .
+// 
+//a
+// CTL
+//a
+//     .
   , {       Id|      Ij       , {    0,    Pt,    Pj,    0}, pgoblin_job    , "job"      } /* 017 */
-//   ,   CTL,    JOB.
-// CTL     ,  
+//   ,  
+//a
+// CTL
+//a
+// ,   
+//a
+// JOB
+//a
+// .
+//a
+// CTL
+//a
+//     ,  
 //     ,      ,
 //       
-//  .     JOB   
+//  .    
+//a
+// JOB
+//a
+//   
 //   ,     
 //         .
 //   :
@@ -275,18 +399,68 @@ const pgoblin_syntax pgoblin =
 //     0.
   , {    Io|Id|   Ij|Is|0x3000, {Po|Pt,    Pt,    Pj,   Ps}, pgoblin_echo   , "echo"     } /* 018 */
 //   STY 0,   OUT    CTL,
-//   OUT     STY,     CTL.
+//  
+//a
+// OUT
+//a
+//    
+//a
+// STY
+//a
+// ,    
+//a
+// CTL
+//a
+// .
   , {    Io|Id|      Is|0x3000, {Po|Pf,    Pt,     0,   Ps}, pgoblin_file   , "file"     } /* 019 */
-//   STY 0,   OUT  ,     CTL,
-//  ,        STY,     CTL.
+//  
+//a
+// STY
+//a
+// 0,  
+//a
+// OUT
+//a
+//  ,    
+//a
+// CTL
+//a
+// ,  ,       
+//a
+// STY
+//a
+// ,    
+//a
+// CTL
+//a
+// .
 //           
 //  ,       .
 //          ,
 //      ,    .
 //     ,     .
   , {    Io|Id|      Is|0x3000, {Po|Pf,    Pt,     0,   Ps}, pgoblin_cat    , "cat"      } /* 01A */
-//   STY 0,   OUT  ,     CTL,
-//  ,        STY,     CTL.
+//  
+//a
+// STY
+//a
+// 0,  
+//a
+// OUT
+//a
+//  ,    
+//a
+// CTL
+//a
+// ,  ,       
+//a
+// STY
+//a
+// ,    
+//a
+// CTL
+//a
+// .
 //           
 //  ,       .
 //          ,
@@ -297,51 +471,160 @@ const pgoblin_syntax pgoblin =
 //         .
 //       ,
 //    .    ,
-//       #return.
-//    0  CON,
-//       ,    ,
+//      
+//a
+// #return
+//a
+// .
+//    0 
+//a
+// CON
+//a
+// ,       ,    ,
 //      ,      
 //     .
-//  CTL  ,         -  .
+// 
+//a
+// CTL
+//a
+//  ,         -  .
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL} /* 01C */
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
 
-  , {       Id|Ii|Ic          , {    0, Pt|Pq,    Pc,   Pq}, pgoblin_perform, "perform"  } /* 020 */
-//  ,  CONN,  ,  CTL.
-//     .    IN,
-//   Pq   ,    
-//  .    CONN.
-//    CTL  Pt,    CON  ,
-//     Pq,      CTL Pq 
-//  ,  0   .   
-//  Pq  ,   IN Pq,   CTL Pq 
-//         .    
+  , {    Io|Id|Ii|Ic          , {Po|Pq, Pt|Pq,    Pc,   Pq}, pgoblin_perform, "perform"  } /* 020 */
+//  , 
+//a
+// CONN
+//a
+// ,  , 
+//a
+// CTL
+//a
+// .
+//     .   
+//a
+// IN
+//a
+// ,  
+//a
+// Pq
+//a
+//   ,    
+//  .   
+//a
+// CONN
+//a
+// .
+//   
+//a
+// CTL
+//a
+// 
+//a
+// Pt
+//a
+// ,   
+//a
+//  CON
+//a
+//   ,
+//    
+//a
+// Pq
+//a
+// ,     
+//a
+//  CTL Pq
+//a
+//  
+//  ,  0   .    
 //  ,      .
-  , {    Io|Id|   Ic          , {Po|Pq,    Pt,    Pc,    0}, pgoblin_binpre , "binpresel"} /* 021 */
-//   CTL     OUT.
-  , {    Io|Id|Ii|Ic          , {Po|Pq,    Pt,    Pc,   Pq}, pgoblin_select , "select"   } /* 022 */
-//        OUT.
-//    IN,     IN Pq  
-//    .    CONN.
-  , {    Io|Id|Ij|Ic|Is|0x3000, {Po|Pm,    Pt,    Pc,   Ps}, pgoblin_binsel , "binselect"} /* 023 */
-//   CTL      OUT   STY.
-  , {    Io|Id|Ij|Ic|Is|0x3000, {Po|Pm,    Pt,    Pc,   Ps}, pgoblin_strsel , "strselect"} /* 024 */
-//   CTL     OUT   STY.
+//  
+//a
+// OUT
+//a
+//  0,   ,      .
+  , {    Io|Id|   Ic          , {Po|Pq, Pt|Pq,    Pc,    0}, pgoblin_binpre , "binpresel"} /* 021 */
+//  
+//a
+// CTL
+//a
+//    
+//a
+// OUT.
+  , {    Io|Id|Ii|Ic          , {Po|Pq, Pt|Pq,    Pc,   Pq}, pgoblin_select , "select"   } /* 022 */
+//       
+// OUT.   
+// IN,    
+//a
+// IN Pq
+//a
+//  
+//    .   
+// CONN.
+  , {    Io|Id|Ij|Ic|Is|0x3000, {Po|Pm, Pt|Pq,    Pc,   Ps}, pgoblin_binsel , "binselect"} /* 023 */
+//   CTL     
+//a
+// OUT
+//a
+//   STY.
+  , {    Io|Id|Ij|Ic|Is|0x3000, {Po|Pm, Pt|Pq,    Pc,   Ps}, pgoblin_strsel , "strselect"} /* 024 */
+//  
+//a
+// CTL
+//a
+//    
+//a
+// OUT
+//a
+//  
+//a
+// STY.
   , { Fx                      , {    0,     0,     0,    0}, NULL           , NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           , NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           , NULL}
-  , {       Id|Ii|Ic          , {    0,    Pt,    Pc,   Pm}, pgoblin_copyin , "copyin"   } /* 028 */
-//  IN     CTL  
+  , {    Io|Id|Ii|Ic          , {Po|Pq,    Pt,    Pc,   Pm}, pgoblin_copyin , "copyin"   } /* 028 */
+// 
+//a
+// IN
+//a
+//    
+//a
+// CTL
+//a
+//  
 //a
 // COPY
+//a
+// .  
+//a
+// OUT
+//a
+//  0,   ,      .
   , {    Io|Id|   Ic|Ij       , {Po|Pm,    Pt,    Pc,    0}, pgoblin_copyout, "copyout"  } /* 029 */
-//   CTL    OUT  
+//  
+//a
+// CTL
+//a
+//   
+//a
+// OUT
+//a
+//  
 //a
 // COPY
   , { Fl|Io|   Ii|   Ij       , {Po|Pm,     0,    Pj,   Pm}, pgoblin_getstr , "getstr"   } /* 02A */
-//  CTL ,   OUT    2   
+// 
+//a
+// CTL
+//a
+// ,  
+//a
+// OUT
+//a
+//    2   
 //a
 // COPY
 //a
@@ -351,44 +634,220 @@ const pgoblin_syntax pgoblin =
 //n
 //      IN.
 //    CTL   .
-  , {    Io|Id|Ii|   Ij       , {Po|Pm,    Pt,    Pj,   Pm}, pgoblin_getdir , "getdir"   } /* 02B */
-//  CTL     ,     .
-//  IN 0,      1      ,
-//     IN.  OUT    
+  , {    Io|Id|Ii|   Ij       , {Po|Pm,    Pt,    Pj,   Pq}, pgoblin_getdir , "getdir"   } /* 02B */
+// 
+//a
+// CTL
+//a
+//     ,     .
+// 
+//a
+// IN
+//a
+// 0,      1      ,
+//     IN. 
+//a
+// OUT
+//a
+//    
 //a
 // COPY
 //a
 //  :
 //u
-// 0x01    ,   0
-// 0x02  
-// 0x04  
-// 0x08 mode 
-// 0x10 uid 
-// 0x20 gid 
+// - 0x01    ,   0
+// - 0x02  
+// - 0x04  
+// - 0x08 mode 
+// - 0x10 uid 
+// - 0x20 gid 
   , {    Io|Id|Ii|   Ij       , {Po|Pm,    Pt,    Pj,   Pm}, pgoblin_getcsv , "getcsv"   } /* 02C */
-//  CSV   COPY .
-//  CTL    2      ,
+//  CSV  
+//a
+// COPY
+//a
+// .
+// 
+//a
+// CTL
+//a
+//    2      ,
 //      ,
 //         ,
 //     NULL  .
 //    ,       
 // ,      .
-//  CTL ,      ';',
+// 
+//a
+// CTL
+//a
+// ,      ';',
 //     '"'.
+  , {    Io|Id|      Ij       , {Po|Pm,    Pt,    Pj,    0}, pgoblin_getopt , "getopt"   } /* 02D */
+// 
+//a
+// OUT
+//a
+//       
+//a
+// COPY
+//a
+//  3 :
+//n
+// -   
+// - 
+// -    text[],  NULL,    .
+//n
+// 
+//a
+// CTL
+//a
+//  ,    ,  
+//  
+//a
+// babolo_setopts (3)
+//a
+// .      
+//a
+// Bpars_NONU
+//a
+// , 1 -  , 0 - .
+//  ,  
+//a
+// Bpars_SYME | Bpars_ESYM | Bpars_EPRM
+//a
+// 
+//a
+// symr
+//a
+//  
+//a
+// Z
+  , {    Io|Id|      Ij       , {Po|Pm,    Pt,    Pj,    0}, pgoblin_getarg , "getarg"   } /* 02E */
+// 
+//a
+// OUT
+//a
+//    
+//a
+// COPY
+//a
+//  2 :
+//n
+// -  ,   0
+// -  
+//n
+// 
+//a
+// CTL
+//a
+// ,   
+//a
+// #getarg
+//a
+//  
+//a
+// #getopt
+//a
+// ,   ,      
+//     
+//a
+// pgoblin
+//a
+// ,   .  
+//a
+// #getopt
+//a
+// 
+//a
+// CTL
+//a
+// ,   ,   ,
+//      .
+//      ,
+//     
+//a
+// #getopt
+//a
+// .
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
-  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
-  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
-
-  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL} /* 030 */
-  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
-  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
-  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
+  , {    Io|Id|   Ic          , {Po|Pq,    Pt,    Pc,    0}, pgoblin_begin  , "begin"    } /* 030 */
+//      pgoblin  ,   .
+//  
+//a
+// BEGIN
+//a
+//  ,  
+//a
+// CON
+//a
+// ,     .
+//     
+//a
+// END
+//a
+//   ,
+//    .  
+//a
+// #begin
+//a
+// -
+//a
+// #end
+//a
+//  
+// 
+//a
+// BEGIN
+//a
+// -
+//a
+// END
+//a
+//    .    
+//       ,      PostgreSQL.
+//  
+//a
+// OUT
+//a
+//  0,   ,      .
+  , {    Io|Id|   Ic          , {Po|Pq,    Pt,    Pc,    0}, pgoblin_end    , "end"      } /* 031 */
+//      
+//a
+// #begin
+//a
+// ,   ,
+//     .
+//    
+//a
+// END
+//a
+//  ,  
+//a
+// CON
+//a
+// .
+//     
+//a
+// END
+//a
+//  ,    .  
+//a
+// OUT
+//a
+//  0,   ,      .
+  , {    Io|Id|   Ic          , {Po|Pq,    Pt,    Pc,    0}, pgoblin_rollbk , "rollback" } /* 032 */
+//  ROLLBACK.  
+//a
+// OUT
+//a
+//  0,   ,      .
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
+  , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL} /* 038 */
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
@@ -601,21 +1060,25 @@ const pgoblin_syntax pgoblin =
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
 
-  , { Fl|         Ic          , {    0,     0,    Pc,    0}, pgoblin_begin  , "begin"    } /* 100 */
-//      pgoblin  ,   .
-//   BEGIN  ,   CON,     .
-//      END   PostgreSQL,
-//    .   #begin - #end  
-//  BEGIN - END    .    
-//       ,      PostgreSQL.
-  , { Fl|         Ic          , {    0,     0,    Pc,    0}, pgoblin_end    , "end"      } /* 101 */
-//       #begin,   ,
-//     .
-//     END  ,   CON.
-//      END   PostgreSQL,
-//    .
+  , {    Io|Id|   Ic          , {Po|Pq,    Pt,    Pc,    0}, pgoblin_begin  , "begin"    } /* 100 */
+  , {    Io|Id|   Ic          , {Po|Pq,    Pt,    Pc,    0}, pgoblin_end    , "end"      } /* 101 */
   , { Fl|Io|   Ii|   Ij    |Ff, {Po|Pm,     0,    Pj,   Pm}, pgoblin_fork   , "fork"     } /* 102 */
-// pgoblin ,      #fork  #exit  #return,
+//a
+// pgoblin
+//a
+// ,     
+//a
+// #fork
+//a
+// 
+//a
+// #exit
+//a
+// 
+//a
+// #return
+//a
+// ,
 //   ,     .
 //         ,
 //     .
@@ -624,32 +1087,124 @@ const pgoblin_syntax pgoblin =
 //         
 //    ,     
 //  .
-//  OUT          ,
-//   IN          ,
+// 
+//a
+// OUT
+//a
+//          ,
+//  
+//a
+// IN
+//a
+//          ,
 //   .
   , { Fl|            Ij       , {    0,     0,    Pj,    0}, pgoblin_wait   , "wait"     } /* 103 */
-//    ,   JOB.
+//    ,  
+//a
+// JOB
+//a
+// .
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL} /* 104 */
   , { Fl|Fd|      Ic          , {    0,     0, Po|Pc,    0}, pgoblin_return , "return"   } /* 105 */
-//      #fork,     #exit  CTL.
-//     #trap,       ,
-//   CON  .
-  , { Fl|Io|   Ii|   Is|0x2000, {Po|Pm,     0,    Ps,   Pq}, pgoblin_display, "display"  } /* 106 */
+//     
+//a
+// #fork
+//a
+// ,    
+//a
+// #exit
+//a
+// 
+//a
+// CTL
+//a
+// .
+//    
+//a
+// #trap
+//a
+// ,       ,
+//  
+//a
+// CON
+//a
+//  .
+  , { Fl|Io|   Ii|Ij|Is|0x2000, {Po|Pm,     0,    Ps,   Pq}, pgoblin_display, "display"  } /* 106 */
 // IN   Pq   OUT      STY.
   , { Fl|Io|   Ii             , {   Pm,     0,     0,Po|Pm}, pgoblin_pipe   , "pipe"     } /* 107 */
-//    OUT    IN.      
+//   
+//a
+// OUT
+//a
+//   
+//a
+// IN
+//a
+// .      
 //     . 0  ,   .
   , { Fl|Io|   Ii|Ic|Is|0x1000, {   Pm, Po|Ps, Po|Pc,Po|Pm}, pgoblin_close  , "close"    } /* 108 */
-//    OUT,   IN,  STY     CON.
-//        IN  OUT .
+//   
+//a
+// OUT
+//a
+// ,  
+//a
+// IN
+//a
+// , 
+//a
+// STY
+//a
+//    
+//a
+// CON
+//a
+// .
+//       
+//a
+// IN
+//a
+// 
+//a
+// OUT
+//a
+// .
 //      0   .
-//   CON,   0,  ,    
+//  
+//a
+// CON
+//a
+// ,   0,  ,    
 //      .
   , { Fl|Io|      Ij|Is|0x3000, {Po|Pt,     0, Po|Pj,Po|Ps}, pgoblin_clear  , "clear"    } /* 109 */
-//  JOB  STY,   0. 0 JOB  STY  .
-//     0 OUT,    Po|Pm.
+// 
+//a
+// JOB
+//a
+// 
+//a
+// STY
+//a
+// ,   0. 0
+//a
+// JOB
+//a
+// 
+//a
+// STY
+//a
+//  .
+//     0
+//a
+// OUT
+//a
+// ,   
+//a
+// Po|Pm.
   , { Fl                      , {    0,     0,     0,    0}, pgoblin_untrap , "untrap"   } /* 10A */
-//    #trap.
+//   
+//a
+// #trap.
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
@@ -657,52 +1212,145 @@ const pgoblin_syntax pgoblin =
   , { Fx                      , {    0,     0,     0,    0}, NULL           ,        NULL}
 
   , { Fl|Io|         Ij       , {Po|Pm,     0,    Pj,    0}, pgoblin_getarg , "getarg"   } /* 110 */
-//  OUT     COPY  2 :
-//n
-//  ,   0
-//  
-//n
-//     ,     pgoblin,
-//  ,     .
   , { Fl|Io|         Ij       , {Po|Pm,     0,    Pj,    0}, pgoblin_getenv , "getenv"   } /* 111 */
 //  OUT     COPY  3 :
 //n
-//    ,   0
-//   
-//  
+// -    ,   0
+// -   
+// -  
   , { Fl|Io|         Ij       , {Po|Pm,     0,    Pj,    0}, pgoblin_getget , "getget"   } /* 112 */
-//  OUT     COPY  3 :
+// 
+//a
+// OUT
+//a
+//    
+//a
+// COPY
+//a
+//  3 :
 //n
-//    ,   0
-//    HTTP GET
-//  
+// -    ,   0
+// -    HTTP GET
+// -  
 //n
-//      CGI,  GET,    getCGIparm.
+//     
+//a
+// CGI
+//a
+// , 
+//a
+// GET
+//a
+// ,   
+//a
+// getCGIparm.
   , { Fl|Io|   Ii|   Ij       , {Po|Pm,     0,    Pj,   Pm}, pgoblin_getpost, "getpost"  } /* 113 */
-//  OUT     COPY  3 :
+// 
+//a
+// OUT
+//a
+//    
+//a
+// COPY
+//a
+//  3 :
 //n
-//    ,   0
-//    HTTP POST
+// -    ,   0
+// -    HTTP POST
+// -  
+//n
+//     
+//a
+// IN
+//a
+// .
+//     
+//a
+// CGI
+//a
+// , 
+//a
+// POST
+//a
+// ,   
+//a
+// getCGIparm.
+  , { Fl|Io|         Ij       , {Po|Pm,     0,    Pj,    0}, pgoblin_getproc, "getproc"  } /* 114 */
+// 
+//a
+// OUT
+//a
+//    
+//a
+// COPY
+//a
+//  3 :
+//n
+// - PID 
+// -  ,   0
+// -  
+//n
+//     .  
+//a
+// /proc/.
+  , { Fl|Io|         Ij       , {Po|Pm,     0,     0,    0}, pgoblin_getjob , "getjob"   } /*!ch[2] */
+// 
+//a
+// OUT
+//a
+//    
+//a
+// COPY
+//a
+//  4 :
+//n
+// -    ,   0
+// -  ,    
+// - PID 
+// -  
+//n
+//     
+//a
+// JOB
+//a
+// . 
+//a
+// #getjob
+//a
 //  
-//n
-//      IN.
-//      CGI,  POST,    getCGIparm.
-  , { Fl|Io|         Ij       , {Po|Pm,     0,    Pj,    0}, pgoblin_getproc, "getproc" } /* 114 */
-//  OUT     COPY  3 :
-//n
-// PID 
-//  ,   0
+//a
+// JOB
+//a
+// 0.
+  , { Fx                      , {    0,     0,     0,    0}, pgoblin_getspq , "getspq"   } /* 116 */
+  , { Fl|Io|   Ii             , {Po|Pm,     0,     0,   Pq}, pgoblin_getmeta, "getmeta"  } /* 117 */
+// 
+//a
+// OUT
+//a
+//       
+//a
+// IN Pq
+//a
 //  
+//a
+// COPY
+//a
+//  7 :
 //n
-//     .   /proc/.
-  , { Io|            Ij       , {Po|Pm,     0,     0,    0}, pgoblin_getjob , "getjob"  } /*!ch[2] */
-//  OUT     COPY  4 :
+// -  ,   0
+// -  
+// -  
+// -  
+// -   ( ,   )
+// NULL
+// NULL
 //n
-//    ,   0
-//  ,    
-// PID 
-//  
-//n
-//      JOB.  #getjob   JOB 0.
-  , { Fx                      , {    0,     0,     0,    0}, pgoblin_getspq , "getspq"  } /* 116 */
+//    
+//a
+// IN
+//a
+//      NULL.
+// 2    NULL    .
+  , { Fl|Io|   Ii             , {Po|Pq,     0,     0,   Pq}, pgoblin_info   , "info"     } /* 118 */
 } };
